mirror

package module
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 18, 2022 License: MIT Imports: 11 Imported by: 0

README

mirror

mirror is command line tool for mirroring a web page.

Installation

go install github.com/yusukebe/mirror/cmd/mirror@latest

Usage

mirror is a command line tool for mirroring web page

Usage:
  mirror [url] [flags]

Flags:
  -A, --agent string        User-Agent name (default "mirror/v0.0.1")
  -h, --help                help for mirror
  -o, --output-dir string   Output Directory (default "output")

Author

Yusuke Wada https://github.com/yusukebe

License

MIT

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

func NewClient

func NewClient(param param) *Client

Directories

Path Synopsis
cmd
mirror command

Jump to